API docs for “spamfighter.core.commands.command.Command”

# Class s.c.c.c.Command(object):

Part of spamfighter.core.commands.command View Source View In Hierarchy

Known subclasses: spamfighter.core.commands.partner.PartneredCommand, spamfighter.core.commands.test.test_apiglue.TestPingCommand, spamfighter.core.commands.test.test_command.FakeCommand, spamfighter.core.commands.test.test_dispatcher.FakeCommand

Базовый класс для всех команд.

Любой производный класс должен быть отнаследован от этого класса и должен реализовывать интерфейс `ICommand`.

Instance Variables | _params | параметры команды (исходный словарь) (type: `dict` )
| _result | результат команды (исходный словарь) (type: `dict` )
| params | обертка над параметрами (type: `_ParamsWrapper` )
| result | обертка над результатом (type: `_ParamsWrapper` )

Method | __init__ | Конструктор команды
Method | getResponse | Сформировать результат команды как хэш, готовый к XML-RPC преобразованию.
Method | getParams | Сформировать параметры команды как хэш, готовый к XML-RPC преобразованию.
Method | checkParams | Проверить наличие всех необходимых параметров команды.
Method | checkResult | Проверить наличие всех необходимых полей в результате выполнения команды.
Method | init | Дополнительный метод, может переопределяться в потомках для выполнения процедуры
Method | finalize | Дополнительный метод, может переопределяться в потомках для выполнения завершения
Method | run | Выполнить команду.
Class | _ParamsWrapper | Класс-обертка для проверки корректности

def __init__(self): (source)
Конструктор команды

def getResponse(self): (source)
Сформировать результат команды как хэш, готовый к XML-RPC преобразованию.

Returns | Deferred `dict`, хеш результата команды (type: `twisted.internet.defer.Deferred` )

def getParams(self): (source)
Сформировать параметры команды как хэш, готовый к XML-RPC преобразованию.

Returns | Deferred `dict`, хеш параметров команды команды (type: `twisted.internet.defer.Deferred` )

def checkParams(self): (source)
Проверить наличие всех необходимых параметров команды.

Raises | errors.CommandParamsMissingException | не хватает параметра

def checkResult(self): (source)
Проверить наличие всех необходимых полей в результате выполнения команды.

Raises | errors.CommandResultMissingException | не хватает значения

def init(self): (source)
overridden in spamfighter.core.commands.partner.PartneredCommand
Дополнительный метод, может переопределяться в потомках для выполнения процедуры дополнительной предварительной инициализации.

Может быть синхронным, а может возвращать `twisted.internet.defer.Deferred`

def finalize(self): (source)
overridden in spamfighter.core.commands.partner.DomainedCommand
Дополнительный метод, может переопределяться в потомках для выполнения завершения обработки команды.

def run(self): (source)
Выполнить команду.

В процессе выполнения команды или проверки условий её выполнения (наличие всех параметров) и т.п., могут возникать исключения, которые будут переданы через errback к deferred, или в случае успешного выполнения вызовется callback.

Returns | deferred, которая будет вызвана после завершения выполнения команды и формирования её результата (type: `defer.Deferred` )